@@ -584,13 +584,6 @@ module_radeon_args="modeset=1"
             """
             self.spawn_chroot(bb_script, silent = True)
 
-    def copy_udev(self):
-        tmp_dir = tempfile.mkdtemp()
-        self.spawn("mount --move %s/dev %s" % (self._root, tmp_dir,))
-        self.spawn("cp /dev/* %s/dev/ -Rp" % (self._root,))
-        self.spawn("mount --move %s %s/dev" % (tmp_dir, self._root,))
-        shutil.rmtree(tmp_dir, True)
-
     def _get_opengl(self, chroot = None):
         """
         get the current OpenGL subsystem (ati,nvidia,xorg-x11)
